==> activity-center-biz-1.0.2-20160620.083718-14-sources.jar: cn/com/duiba/activity/center/biz/service/ActivityCategoryService.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityCategoryService.java
 * Package Name:cn.com.duiba.activity.center.biz.service
 * Date:2016年6月7日上午8:56:44
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service;

import java.util.List;

import cn.com.duiba.activity.center.api.dto.ActivityCategoryDto;
import cn.com.duiba.activity.center.biz.entity.ActivityCategoryEntity;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:ActivityCategoryService <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2016年6月7日 上午8:56:44 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface ActivityCategoryService {
    /**
     * 创建一个活动分类
     *
     * @author xuhengfei
     * @param name
     * @return
     * @since JDK 1.6
     */
    Long createCategory(String name);
    /**
     * 修改活动分类的皮肤
     *
     * @author xuhengfei
     * @param id
     * @param content
     * @return
     * @since JDK 1.6
     */
    Boolean editCategoryContent(long id,String content);
    /**
     * 启用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    Boolean enableCategory(long id);
    /**
     * 禁用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    Boolean disableCategory(long id);
    /**
     * 查询所有的活动分类
     *
     * @author xuhengfei
     * @return
     * @since JDK 1.6
     */
    List<ActivityCategoryEntity> findAll();
    /**
     * 查询默认的分类
     *
     * @author xuhengfei
     * @return
     * @since JDK 1.6
     */
    ActivityCategoryEntity findDefaultCategory();
}

==> activity-center-biz-1.1.3-20160719.030755-1-sources.jar: cn/com/duiba/activity/center/biz/service/ActivityCategoryService.java <==
/**
 * Project Name:activity-center-biz
 * File Name:ActivityCategoryService.java
 * Package Name:cn.com.duiba.activity.center.biz.service
 * Date:2016年6月7日上午8:56:44
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.biz.service;

import java.util.List;

import cn.com.duiba.activity.center.biz.entity.ActivityCategoryEntity;

/**
 * ClassName:ActivityCategoryService <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2016年6月7日 上午8:56:44 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface ActivityCategoryService {
    /**
     * 创建一个活动分类
     *
     * @author xuhengfei
     * @param name
     * @return
     * @since JDK 1.6
     */
    Long createCategory(String name);
    /**
     * 修改活动分类的皮肤
     *
     * @author xuhengfei
     * @param id
     * @param content
     * @return
     * @since JDK 1.6
     */
    Boolean editCategoryContent(long id,String content);
    /**
     * 启用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    Boolean enableCategory(long id);
    /**
     * 禁用一个活动分类
     *
     * @author xuhengfei
     * @param id
     * @return
     * @since JDK 1.6
     */
    Boolean disableCategory(long id);
    /**
     * 查询所有的活动分类
     *
     * @author xuhengfei
     * @return
     * @since JDK 1.6
     */
    List<ActivityCategoryEntity> findAll();
    /**
     * 查询默认的分类
     *
     * @author xuhengfei
     * @return
     * @since JDK 1.6
     */
    ActivityCategoryEntity findDefaultCategory();
	ActivityCategoryEntity findById(long id);
}
